==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerCaptureHTTPCookieBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder>{
  public IngressControllerCaptureHTTPCookieBuilder() {
    this(false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerCaptureHTTPCookie(), validationEnabled);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerCaptureHTTPCookie(), validationEnabled);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance) {
    this(fluent, instance, false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMatchType(instance.getMatchType()); 
    fluent.withMaxLength(instance.getMaxLength()); 
    fluent.withName(instance.getName()); 
    fluent.withNamePrefix(instance.getNamePrefix()); 
    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance) {
    this(instance,false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMatchType(instance.getMatchType()); 
    this.withMaxLength(instance.getMaxLength()); 
    this.withName(instance.getName()); 
    this.withNamePrefix(instance.getNamePrefix()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie build() {
    IngressControllerCaptureHTTPCookie buildable = new IngressControllerCaptureHTTPCookie(fluent.getMatchType(),fluent.getMaxLength(),fluent.getName(),fluent.getNamePrefix());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerCaptureHTTPCookieBuilder that = (IngressControllerCaptureHTTPCookieBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerCaptureHTTPCookieBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieBuilder>{
  public IngressControllerCaptureHTTPCookieBuilder() {
    this(false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerCaptureHTTPCookie(), validationEnabled);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerCaptureHTTPCookie(), validationEnabled);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance) {
    this(fluent, instance, false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMatchType(instance.getMatchType()); 
    fluent.withMaxLength(instance.getMaxLength()); 
    fluent.withName(instance.getName()); 
    fluent.withNamePrefix(instance.getNamePrefix()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance) {
    this(instance,false);
  }
  public IngressControllerCaptureHTTPCookieBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMatchType(instance.getMatchType()); 
    this.withMaxLength(instance.getMaxLength()); 
    this.withName(instance.getName()); 
    this.withNamePrefix(instance.getNamePrefix()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookie build() {
    IngressControllerCaptureHTTPCookie buildable = new IngressControllerCaptureHTTPCookie(fluent.getMatchType(),fluent.getMaxLength(),fluent.getName(),fluent.getNamePrefix());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerCaptureHTTPCookieBuilder that = (IngressControllerCaptureHTTPCookieBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
